@@ -31,7 +31,7 @@ def get_picture_url(page_url):
     match = re.search(
         "/az/hprichbg/rb/.+?(?=')", r.text)
     picture_url = match.group()
-    if len(r.history):
+    if r.history:
         ZH = 1
         picture_url = 'http://s.cn.bing.net' + picture_url
     else:
@@ -71,8 +71,8 @@ def get_picture_name(picture_url):
 
 
 def set_wallpaper(picture_path):
-    os.system('gsettings set org.gnome.desktop.background picture-uri file:' +
-              picture_path)
+    os.system('DISPLAY=:0 GSETTINGS_BACKEND=dconf /usr/bin/gsettings set org.'
+              'gnome.desktop.background picture-uri file://' + picture_path)
 
 
 def main():
@@ -83,8 +83,8 @@ def main():
         print "ConnectionError,check your network please."
         print "Will try again after 5 minutes."
         time.sleep(300)
-        picture_url = get_picture_url("http://cn.bing.com")
-        download_and_set(picture_url)
+        picture_url, ZH = get_picture_url("http://www.bing.com")
+        download_and_set(picture_url, ZH)
     except TypeError:
         print "Set the directory to save Bing's imgs first."
         print "For more information, use --help."
